#define matClip		c_mat2

//v0: xyzw:WorldPos
//v1: xy:NormalUV, zw:MaskUV
//v2: xyzw:ScreenPos


//@vs
///////////////////////////////////////////////////////////////////////////////////////////////////////
#ifdef V_SHADER

void main () 
{	
	float3 wP = (matW * POS0).xyz;					//world pos
	float4 sP = (matVP * float4(wP, 1.0));	//screen pos

	float3 wE = normalize(EyePos - wP);

	float dist = calc_distance (EyePos, wP);
	float fog = 1.0 - get_dis_alpha (dist, FogNear, FogFar);
	float2 normalUV = wP.xy / 500.0;

	vs_out_p = sP;

	vs_out_0 = float4 (wE.xyz, fog);

	vs_out_1.x = 7.0 + 3.0 * fog;
	vs_out_1.y = 0.0;
	vs_out_1.zw = TUV0.xy;

	float4 scrpos = sP;//ScreenPos;
	scrpos /= scrpos.w;
	float2 suv = 0.5 + 0.5 * scrpos.xy * float2 (1.0, -1.0);
	float iz = 0.1 / scrpos.z;
	vs_out_2.xy = suv;
	vs_out_2.z = iz;
	vs_out_2.w = 0.0;

	float uv0inc = CTIME_MS * UV0Speed;
	float uv1inc = CTIME_MS * UV1Speed;

	vs_out_3.xy = normalUV * UV0Mul + uv0inc;
	vs_out_3.zw = normalUV * UV0Mul + uv0inc;
	vs_out_4.xy = normalUV * UV1Mul - uv1inc;
	vs_out_4.zw = normalUV * UV1Mul - uv1inc;
}

#endif


//@ps
///////////////////////////////////////////////////////////////////////////////////////////////////////
#ifdef P_SHADER

#define EyeDir							ps_in_0.xyz
#define FogRatio						ps_in_0.w
#define NormalRatio					ps_in_1.x
#define MaskUV							ps_in_1.zw
#define ScreenUV						ps_in_2.xy
#define ScreenIZ						ps_in_2.z
#define NormalUV00					ps_in_3.xy
#define NormalUV01					ps_in_3.zw
#define NormalUV10					ps_in_4.xy
#define NormalUV11					ps_in_4.zw

#define samp_bump(_uv)			texture2D (c_samp0, _uv)
#define samp_fresnel(_uv)		texture2D (c_samp1, _uv)
#define samp_refr(_uv)			texture2D (c_samp2, _uv)
#define samp_refl(_uv)			texture2D (c_samp3, _uv)


void main () 
{ 
	float3 normal0 = samp_bump (NormalUV00).xyz * 2.0 - 1.0; normal0.z *= NormalRatio;
	float3 normal1 = samp_bump (NormalUV10).xyz * 2.0 - 1.0; normal1.z *= NormalRatio;
	float3 wN = normalize (normal0+normal1);
	float3 wE = EyeDir;

	float3 R = reflect (-wE.xzy, wN.xzy);
	float f = R.x * wN.x + R.y * wN.z + R.z * wN.y;
	f = samp_fresnel (float2(f, 0)).w;

	float3 rcolor = float3 (0.17, 0.27, 0.26);
	rcolor = lerp (rcolor, float3 (0.17, 0.27, 0.26)*0.5, f);
	ps_out_c = float4 (rcolor, (1.0-FogRatio));

	//float2 _ruv = (ScreenUV - ScreenIZ*wN.xy);
	//_ruv.y = 1.0 - _ruv.y;

	//float4 refl = textureCB (c_cube, R).xyzw;
	//float4 refr = float4 (0.17, 0.27, 0.26, 1.0);	//samp_refr (_ruv).xyzw;
	//float3 rcolor = lerp (refr.xyz, refl.xyz, f);

	//ps_out_c = float4 (rcolor, (1.0-FogRatio)*0.8);
}

#endif






