#define matClip		c_mat2

//v0: xyzw:WorldPos
//v1: xy:NormalUV, zw:MaskUV
//v2: xyzw:ScreenPos


//@vs
///////////////////////////////////////////////////////////////////////////////////////////////////////
#ifdef V_SHADER

void main () 
{	
#ifdef sd_SeaNormal
	float3 wP = (matW * POS0).xyz;					//world pos
	float4 sP = (matVP * float4(wP, 1.0));	//screen pos

	float dist = calc_distance (EyePos, wP);
	float fog = get_dis_alpha (dist, FogNear, FogFar);
	float2 normalUV = wP.xy / 500.0;

	float disR = get_dis_alpha (dist, 30.0, 80.0);
	float normal_comp = lerp (20.0, NormalComp, disR*disR);

	vs_out_p = sP;
	vs_out_0 = SeaColor;
	vs_out_0.w *= fog;

	float uv0inc = CTIME_MS * UV0Speed;
	float uv1inc = CTIME_MS * UV1Speed;

	vs_out_1.xy = normalUV * UV0Mul + uv0inc;
	vs_out_1.zw = normalUV * UV0Mul + uv0inc;
	vs_out_2.xy = normalUV * UV1Mul - uv1inc;
	vs_out_2.zw = normalUV * UV1Mul - uv1inc;
	vs_out_3.xyz = normalize (EyePos - wP);
	vs_out_3.w = normal_comp;
	vs_out_4.xyz = normalize (float3 (1, 1, 1));
#endif

#ifdef sd_SeaHigh
	float3 wP = (matW * POS0).xyz;					//world pos
	float4 sP = (matVP * float4(wP, 1.0));	//screen pos

	float dist = calc_distance (EyePos, wP);
	float fog = get_dis_alpha (dist, FogNear, FogFar);
	float2 normalUV = wP.xy / 500.0;

	float disR = get_dis_alpha (dist, 30.0, 80.0);
	float normal_comp = lerp (20.0, NormalComp, disR*disR);

	vs_out_p = sP;
	vs_out_0 = SeaColor;
	vs_out_0.w *= fog;

	float uv0inc = CTIME_MS * UV0Speed;
	float uv1inc = CTIME_MS * UV1Speed;

	vs_out_1.xy = normalUV * UV0Mul + uv0inc;
	vs_out_1.zw = normalUV * UV0Mul + uv0inc;
	vs_out_2.xy = normalUV * UV1Mul - uv1inc;
	vs_out_2.zw = normalUV * UV1Mul - uv1inc;
	vs_out_3.xyz = normalize (EyePos - wP);
	vs_out_3.w = normal_comp;
	vs_out_4.xyz = normalize (float3 (1, 1, 1));
#endif


#ifdef sd_SeaSimple
	float3 wP = (matW * POS0).xyz;					//world pos

	float dist = calc_distance (EyePos, wP);
	float fog = get_dis_alpha (dist, FogNear*0.5, FogFar);

	vs_out_p = (matVP * float4(wP, 1.0));	//screen pos
	vs_out_0 = SeaColor;
	vs_out_0.w *= fog;
#endif

}

#endif


//@ps
///////////////////////////////////////////////////////////////////////////////////////////////////////
#ifdef P_SHADER

#define WaterColor				ps_in_0
#define NormalUV00				ps_in_1.xy
#define NormalUV01				ps_in_1.zw
#define NormalUV10				ps_in_2.xy
#define NormalUV11				ps_in_2.zw
#define EyeDir						ps_in_3.xyz
#define NormalR						ps_in_3.w
#define SunVec						ps_in_4.xyz

#define samp_bump(_uv)			texture2D (c_samp0, _uv)
#define samp_fresnel(_uv)		texture2D (c_samp1, _uv)

void main () 
{ 
#ifdef sd_SeaNormal
	float3 normal0 = samp_bump (NormalUV00).xyz * 2.0 - 1.0; normal0.z *= NormalR;
	float3 normal1 = samp_bump (NormalUV10).xyz * 2.0 - 1.0; normal1.z *= NormalR;
	float3 wN = normalize (normal0+normal1);

	float3 R = reflect (-EyeDir.xzy, wN.xzy);
	float f = R.x * wN.x + R.y * wN.z + R.z * wN.y;
	f = samp_fresnel (float2(f, 0)).w;

	float4 refl = textureCB (c_cube, R).xyzw;
	float3 rcolor = lerp (WaterColor.xyz, refl.xyz, saturate (f+FresnelRatio));

	ps_out_c = float4 (rcolor, WaterColor.w);

#endif

#ifdef sd_SeaHigh
	float3 normal0 = samp_bump (NormalUV00).xyz * 2.0 - 1.0; normal0.z *= NormalR;
	float3 normal1 = samp_bump (NormalUV10).xyz * 2.0 - 1.0; normal1.z *= NormalR;
	float3 wN = normalize (normal0+normal1);

	float3 R = reflect (-EyeDir.xzy, wN.xzy);
	float f = R.x * wN.x + R.y * wN.z + R.z * wN.y;
	f = samp_fresnel (float2(f, 0)).w;

	//float3 sunlight = SunIntensity * pow(saturate(dot(R, SunVec)), SunPower) * SunColor;
	//float4 refl = textureCB (c_cube, R).xyzw;
	//float3 rcolor = lerp (WaterColor.xyz, refl.xyz+sunlight, saturate (f+FresnelRatio));


	float4 refl = textureCB(c_cube, R).xyzw;
	float3 rcolor = lerp(WaterColor.xyz, refl.xyz, saturate(f + FresnelRatio));

	ps_out_c = float4 (rcolor, WaterColor.w);

#endif

#ifdef sd_SeaSimple
	ps_out_c = float4 (WaterColor.xyz, WaterColor.w);
#endif

}

#endif






